/*
 * pxtest.c -- silly program checking px500 features
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/ioctl.h>

#include "px500.h"

char *prgname;
char *devname = "/dev/px0ctl";

void ioexit(void)
{
    fprintf(stderr,"%s: %s: %s\n",prgname, devname, strerror(errno));
    exit(1);
}

int main(int argc, char **argv)
{
    int fd, res = 0;
    Px_Dev dev;

    prgname = argv[0];
    if (argc > 1) devname = argv[1];

    printf("%s: using device %s\n",argv[0],devname);
    if (argc > 2)
	printf("%s: ignoring extra arguments\n",argv[0]);

    fd = open(devname,O_RDWR);
    if (fd < 0) {
	fprintf(stderr, "%s: %s: %s\n",argv[0], devname, strerror(errno));
	exit(1);
    }

    if ((res = Px_GetDev(fd,&dev)) < 0) ioexit();
    printf("  low level information:\n");
    printf("    pci: bus %i, device %i, function %i\n",
	   dev.bus, dev.device>>3, dev.device&7);
    printf("    map buffer: 0x%08lx\n",(unsigned long)dev.mapbuffer);
    printf("    dma buffer: 0x%08lx\n",(unsigned long)dev.dmabuffer);
    printf("    dma size: %08x\n", dev.dmasize);
    printf("    image size (%ix%i): %i\n",
	   dev.xsize, dev.ysize, dev.imagesize);
    printf("    registers at 0x%08lx, remapped at 0x%08lx\n",
	   (unsigned long)dev.phys_add, (unsigned long) dev.regs);
    printf("    usage %i, isup %i\n",dev.usage, dev.isup);
    printf("    irq %i, currently %i\n", dev.irq, dev.irq_active);
    

    if ((res = Px_Revision(fd)) < 0) ioexit();
    printf("    hardware revision: 0x%02x\n",res);

    if ((res = Px_ProtKey(fd)) < 0) ioexit();
    printf("    protection key: 0x%02x\n",res);

    if ((res = Px_HasRam(fd)) < 0) ioexit();
    printf("    has cache ram: %s\n",res ? "yes" : "no");
    

    if ((res = Px_HaveVideo(fd)) < 0) ioexit();
    printf("    have video: %i\n",res);

    if ((res = Px_VideoType(fd)) < 0) ioexit();
    printf("    video type: %s\n",res==PX_PAL_VIDEO ? "pal" : "ntsc");

    return 0;
}
